flutter_image_hash library

Classes

BlurHashCore
Pure Dart implementation of BlurHash decoding
ImageHash
A widget that displays a placeholder from a BlurHash string or a blurred thumbnail. It can also load a network image and seamlessly crossfade to it once loaded.